@@ -1,23 +1,9 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
- *  Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATECOMPLETIONWIDGET_H
 #define KATECOMPLETIONWIDGET_H
@@ -27,9 +13,9 @@
 
 #include <ktexteditor_export.h>
 
-#include <ktexteditor/movingrange.h>
 #include <ktexteditor/codecompletioninterface.h>
 #include <ktexteditor/codecompletionmodel.h>
+#include <ktexteditor/movingrange.h>
 
 class QToolButton;
 class QPushButton;
@@ -88,6 +74,7 @@ public:
     void registerCompletionModel(KTextEditor::CodeCompletionModel *model);
     void unregisterCompletionModel(KTextEditor::CodeCompletionModel *model);
     bool isCompletionModelRegistered(KTextEditor::CodeCompletionModel *model) const;
+    QList<KTextEditor::CodeCompletionModel *> codeCompletionModels() const;
 
     int automaticInvocationDelay() const;
     void setAutomaticInvocationDelay(int delay);
@@ -192,7 +179,6 @@ private:
     void clear();
     // Switch cursor between argument-hint list / completion-list
     void switchList();
-    KTextEditor::Range determineRange() const;
     void completionRangeChanged(KTextEditor::CodeCompletionModel *, const KTextEditor::Range &word);
 
     void deleteCompletionRanges();
