@@ -1,32 +1,19 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2002-2010 Anders Lund <anders@alweb.dk>
- *
- *  Rewritten based on code of Copyright (c) 2002 Michael Goffioul <kdeprint@swing.be>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2002-2010 Anders Lund <anders@alweb.dk>
+
+    Rewritten based on code of:
+    SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "printconfigwidgets.h"
 
 #include "kateglobal.h"
-#include "kateschema.h"
+#include "katesyntaxmanager.h"
 
 #include <KColorButton>
-#include <KComboBox>
+#include <QComboBox>
 #include <KConfigGroup>
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -501,9 +488,9 @@ KatePrintLayout::KatePrintLayout(QWidget *parent)
 
     QHBoxLayout *hb = new QHBoxLayout();
     lo->addLayout(hb);
-    QLabel *lSchema = new QLabel(i18n("&Schema:"), this);
+    QLabel *lSchema = new QLabel(i18n("&Color theme:"), this);
     hb->addWidget(lSchema);
-    cmbSchema = new KComboBox(this);
+    cmbSchema = new QComboBox(this);
     hb->addWidget(cmbSchema);
     cmbSchema->setEditable(false);
     lSchema->setBuddy(cmbSchema);
@@ -548,19 +535,19 @@ KatePrintLayout::KatePrintLayout(QWidget *parent)
     sbBoxMargin->setValue(6);
     gbBoxProps->setEnabled(false);
 
-    const auto schemas = KTextEditor::EditorPrivate::self()->schemaManager()->list();
-    for (const KateSchema &schema : schemas) {
-        cmbSchema->addItem(schema.translatedName(), QVariant(schema.rawName));
+    const auto themes = KateHlManager::self()->sortedThemes();
+    for (const auto &theme : themes) {
+        cmbSchema->addItem(theme.translatedName(), QVariant(theme.name()));
     }
 
     // default is printing, MUST BE THERE
     cmbSchema->setCurrentIndex(cmbSchema->findData(QVariant(QStringLiteral("Printing"))));
 
     // whatsthis
-    cmbSchema->setWhatsThis(i18n("Select the color scheme to use for the print."));
+    cmbSchema->setWhatsThis(i18n("Select the color theme to use for the print."));
     cbDrawBackground->setWhatsThis(
         i18n("<p>If enabled, the background color of the editor will be used.</p>"
-             "<p>This may be useful if your color scheme is designed for a dark background.</p>"));
+             "<p>This may be useful if your color theme is designed for a dark background.</p>"));
     cbEnableBox->setWhatsThis(
         i18n("<p>If enabled, a box as defined in the properties below will be drawn "
              "around the contents of each page. The Header and Footer will be separated "
