@@ -1,47 +1,35 @@
-/* This file is part of the KDE libraries
-  Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
-  Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-  Copyright (C) 2001-2010 Joseph Wenninger <jowenn@kde.org>
-  Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+/*
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001-2010 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef kate_view_h
 #define kate_view_h
 
-#include <ktexteditor/view.h>
-#include <ktexteditor/texthintinterface.h>
-#include <ktexteditor/inlinenoteinterface.h>
-#include <ktexteditor/markinterface.h>
+#include <ktexteditor/annotationinterface.h>
 #include <ktexteditor/codecompletioninterface.h>
 #include <ktexteditor/configinterface.h>
-#include <ktexteditor/annotationinterface.h>
+#include <ktexteditor/inlinenoteinterface.h>
 #include <ktexteditor/mainwindow.h>
+#include <ktexteditor/markinterface.h>
+#include <ktexteditor/texthintinterface.h>
+#include <ktexteditor/view.h>
 
+#include <QMenu>
+#include <QModelIndex>
 #include <QPointer>
 #include <QScopedPointer>
-#include <QModelIndex>
-#include <QMenu>
 #include <QSpacerItem>
 
 #include <array>
 
-#include "katetextrange.h"
-#include "katetextfolding.h"
 #include "katerenderer.h"
+#include "katetextfolding.h"
+#include "katetextrange.h"
 
 namespace KTextEditor
 {
@@ -87,7 +75,7 @@ namespace KTextEditor
 //
 class KTEXTEDITOR_EXPORT ViewPrivate : public KTextEditor::View,
                                        public KTextEditor::TextHintInterface,
-                                       public KTextEditor::CodeCompletionInterface,
+                                       public KTextEditor::CodeCompletionInterfaceV2,
                                        public KTextEditor::ConfigInterface,
                                        public KTextEditor::InlineNoteInterface,
                                        public KTextEditor::AnnotationViewInterfaceV2
@@ -96,6 +84,7 @@ class KTEXTEDITOR_EXPORT ViewPrivate : public KTextEditor::View,
     Q_INTERFACES(KTextEditor::TextHintInterface)
     Q_INTERFACES(KTextEditor::ConfigInterface)
     Q_INTERFACES(KTextEditor::CodeCompletionInterface)
+    Q_INTERFACES(KTextEditor::CodeCompletionInterfaceV2)
     Q_INTERFACES(KTextEditor::AnnotationViewInterface)
     Q_INTERFACES(KTextEditor::AnnotationViewInterfaceV2)
     Q_INTERFACES(KTextEditor::InlineNoteInterface)
@@ -136,6 +125,12 @@ public Q_SLOTS:
     void copy() const;
 
 private Q_SLOTS:
+    /**
+     * Paste the global mouse selection. Support for Selection is provided only
+     * on systems with a global mouse selection (e.g. X11).
+     */
+    void pasteSelection();
+
     /**
      * Wrap lines touched by the selection with respect of existing paragraphs.
      * Work is done by KTextEditor::DocumentPrivate::wrapParagraph
@@ -233,16 +228,20 @@ public:
     bool toggleFoldingsInRange(int line);
 
     //
-    // KTextEditor::CodeCompletionInterface2
+    // KTextEditor::CodeCompletionInterfaceV2
     //
 public:
     bool isCompletionActive() const override;
     void startCompletion(const KTextEditor::Range &word, KTextEditor::CodeCompletionModel *model) override;
+    void startCompletion(const Range &word,
+                         const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>(),
+                         KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation) override;
     void abortCompletion() override;
     void forceCompletion() override;
     void registerCompletionModel(KTextEditor::CodeCompletionModel *model) override;
     void unregisterCompletionModel(KTextEditor::CodeCompletionModel *model) override;
     bool isCompletionModelRegistered(KTextEditor::CodeCompletionModel *model) const;
+    QList<KTextEditor::CodeCompletionModel *> codeCompletionModels() const override;
     bool isAutomaticInvocationEnabled() const override;
     void setAutomaticInvocationEnabled(bool enabled = true) override;
 
@@ -756,6 +755,8 @@ private:
     QAction *m_copy;
     QAction *m_copyHtmlAction;
     QAction *m_paste;
+    // always nullptr if paste selection isn't supported
+    QAction *m_pasteSelection = nullptr;
     QAction *m_selectAll;
     QAction *m_deSelect;
 
